@@ -30,7 +30,7 @@ import re
 import tokenize
 
 
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 
 
 try:
@@ -72,6 +72,7 @@ def _format_code(source,
     previous_line = ''
     last_row = 0
     last_column = -1
+    only_comments_so_far = True
     for token in tokenize.generate_tokens(sio.readline):
         token_type = token[0]
         token_string = token[1]
@@ -93,11 +94,18 @@ def _format_code(source,
         if start_column > last_column:
             formatted += line[last_column:start_column]
 
-        if (token_type == tokenize.STRING and
-                starts_with_triple(token_string) and
-                previous_token_type == tokenize.INDENT):
+        if (
+            token_type == tokenize.STRING and
+            starts_with_triple(token_string) and
+            (previous_token_type == tokenize.INDENT or only_comments_so_far)
+        ):
+            if only_comments_so_far:
+                indentation = ''
+            else:
+                indentation = previous_token_string
+
             formatted += format_docstring(
-                previous_token_string,
+                indentation,
                 token_string,
                 summary_wrap_length=summary_wrap_length,
                 pre_summary_newline=pre_summary_newline,
@@ -105,6 +113,9 @@ def _format_code(source,
         else:
             formatted += token_string
 
+        if token_type not in [tokenize.COMMENT, tokenize.NEWLINE, tokenize.NL]:
+            only_comments_so_far = False
+
         previous_token_string = token_string
         previous_token_type = token_type
         previous_line = line
@@ -188,8 +199,12 @@ def indent_non_indented(line, indentation):
 
 def is_probably_beginning_of_sentence(line):
     """Return True if this line begins a new sentence."""
+    # Check heuristically for a parameter list.
+    if re.search(r'\s-\s', line):
+        return True
+
     character = line.strip()[0]
-    return character.isupper() or not character.isalnum() or '-' in line
+    return character.isupper() or not character.isalnum()
 
 
 def split_summary_and_description(contents):
